@@ -86,7 +86,7 @@
 #define KSERVICE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KSERVICE_NO_DEPRECATED
-#  define KSERVICE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56100
+#  define KSERVICE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56600
 #endif
 #ifdef KSERVICE_NO_DEPRECATED_WARNINGS
 #  define KSERVICE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KSERVICE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KSERVICE_DEPRECATED_WARNINGS_SINCE KSERVICE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KSERVICE_DEPRECATED_WARNINGS_SINCE 0x56100
+#    define KSERVICE_DEPRECATED_WARNINGS_SINCE 0x56600
 #  endif
 #endif
 
@@ -217,6 +217,12 @@
 #else
 #  define KSERVICE_DEPRECATED_VERSION_5_90(text)
 #endif
+
+#if KSERVICE_DEPRECATED_WARNINGS_SINCE >= 0x56600
+#  define KSERVICE_DEPRECATED_VERSION_5_102(text) KSERVICE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KSERVICE_DEPRECATED_VERSION_5_102(text)
+#endif
 #define KSERVICE_DEPRECATED_VERSION_5(minor, text)      KSERVICE_DEPRECATED_VERSION_5_##minor(text)
 #define KSERVICE_DEPRECATED_VERSION(major, minor, text) KSERVICE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KSERVICE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KSERVICE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
@@ -282,7 +288,7 @@
 #define KSERVICE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KSERVICE_NO_DEPRECATED
-#  define KSERVICE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56100
+#  define KSERVICE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56600
 #endif
 #ifdef KSERVICE_NO_DEPRECATED_WARNINGS
 #  define KSERVICE_DEPRECATED_WARNINGS_SINCE 0
@@ -292,7 +298,7 @@
 #  ifdef KSERVICE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KSERVICE_DEPRECATED_WARNINGS_SINCE KSERVICE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KSERVICE_DEPRECATED_WARNINGS_SINCE 0x56100
+#    define KSERVICE_DEPRECATED_WARNINGS_SINCE 0x56600
 #  endif
 #endif
 
@@ -413,6 +419,12 @@
 #else
 #  define KSERVICE_DEPRECATED_VERSION_5_90(text)
 #endif
+
+#if KSERVICE_DEPRECATED_WARNINGS_SINCE >= 0x56600
+#  define KSERVICE_DEPRECATED_VERSION_5_102(text) KSERVICE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KSERVICE_DEPRECATED_VERSION_5_102(text)
+#endif
 #define KSERVICE_DEPRECATED_VERSION_5(minor, text)      KSERVICE_DEPRECATED_VERSION_5_##minor(text)
 #define KSERVICE_DEPRECATED_VERSION(major, minor, text) KSERVICE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KSERVICE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KSERVICE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
